# About

This directory contains the protobuf-based interface definition (IDL) for the
BigQuery V2 service (bigquery.googleapis.com).

BigQuery V2 does not expose a gRPC-based transport definition, and these
artifacts are being published to enable work on updating existing REST-based
clients with more functionality.

We discourage their direct use externally at this time, and will
communicate changes here and via channels like the per-language release notes.